# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'zad/Designer/settings.ui'
#
# Created by: PyQt5 UI code generator 5.15.4
#
# WARNING: Any manual changes made to this file will be lost when pyuic5 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_settingsTabWidget(object):
    def setupUi(self, settingsTabWidget):
        settingsTabWidget.setObjectName("settingsTabWidget")
        settingsTabWidget.resize(389, 373)
        self.verticalLayout_2 = QtWidgets.QVBoxLayout(settingsTabWidget)
        self.verticalLayout_2.setContentsMargins(-1, 17, -1, -1)
        self.verticalLayout_2.setObjectName("verticalLayout_2")
        self.tabWidget = QtWidgets.QTabWidget(settingsTabWidget)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.tabWidget.sizePolicy().hasHeightForWidth())
        self.tabWidget.setSizePolicy(sizePolicy)
        self.tabWidget.setMinimumSize(QtCore.QSize(0, 0))
        self.tabWidget.setBaseSize(QtCore.QSize(365, 349))
        self.tabWidget.setAutoFillBackground(False)
        self.tabWidget.setLocale(QtCore.QLocale(QtCore.QLocale.English, QtCore.QLocale.Germany))
        self.tabWidget.setTabShape(QtWidgets.QTabWidget.Rounded)
        self.tabWidget.setElideMode(QtCore.Qt.ElideNone)
        self.tabWidget.setMovable(False)
        self.tabWidget.setObjectName("tabWidget")
        self.GeneralTab = QtWidgets.QWidget()
        self.GeneralTab.setObjectName("GeneralTab")
        self.verticalLayout = QtWidgets.QVBoxLayout(self.GeneralTab)
        self.verticalLayout.setObjectName("verticalLayout")
        self.formLayout = QtWidgets.QFormLayout()
        self.formLayout.setFieldGrowthPolicy(QtWidgets.QFormLayout.ExpandingFieldsGrow)
        self.formLayout.setObjectName("formLayout")
        self.masterServerLabel = QtWidgets.QLabel(self.GeneralTab)
        self.masterServerLabel.setObjectName("masterServerLabel")
        self.formLayout.setWidget(0, QtWidgets.QFormLayout.LabelRole, self.masterServerLabel)
        self.masterServerLineEdit = QtWidgets.QLineEdit(self.GeneralTab)
        self.masterServerLineEdit.setObjectName("masterServerLineEdit")
        self.formLayout.setWidget(0, QtWidgets.QFormLayout.FieldRole, self.masterServerLineEdit)
        self.ddnsKeyFileLabel = QtWidgets.QLabel(self.GeneralTab)
        self.ddnsKeyFileLabel.setObjectName("ddnsKeyFileLabel")
        self.formLayout.setWidget(1, QtWidgets.QFormLayout.LabelRole, self.ddnsKeyFileLabel)
        self.ddnsKeyFileLineEdit = QtWidgets.QLineEdit(self.GeneralTab)
        self.ddnsKeyFileLineEdit.setObjectName("ddnsKeyFileLineEdit")
        self.formLayout.setWidget(1, QtWidgets.QFormLayout.FieldRole, self.ddnsKeyFileLineEdit)
        self.serverForZoneTransferLabel = QtWidgets.QLabel(self.GeneralTab)
        self.serverForZoneTransferLabel.setObjectName("serverForZoneTransferLabel")
        self.formLayout.setWidget(2, QtWidgets.QFormLayout.LabelRole, self.serverForZoneTransferLabel)
        self.serverForZoneTransferLineEdit = QtWidgets.QLineEdit(self.GeneralTab)
        self.serverForZoneTransferLineEdit.setObjectName("serverForZoneTransferLineEdit")
        self.formLayout.setWidget(2, QtWidgets.QFormLayout.FieldRole, self.serverForZoneTransferLineEdit)
        self.initialDomainLabel = QtWidgets.QLabel(self.GeneralTab)
        self.initialDomainLabel.setObjectName("initialDomainLabel")
        self.formLayout.setWidget(3, QtWidgets.QFormLayout.LabelRole, self.initialDomainLabel)
        self.initialDomainLineEdit = QtWidgets.QLineEdit(self.GeneralTab)
        self.initialDomainLineEdit.setObjectName("initialDomainLineEdit")
        self.formLayout.setWidget(3, QtWidgets.QFormLayout.FieldRole, self.initialDomainLineEdit)
        self.defaultPrefixIPv4Label = QtWidgets.QLabel(self.GeneralTab)
        self.defaultPrefixIPv4Label.setObjectName("defaultPrefixIPv4Label")
        self.formLayout.setWidget(4, QtWidgets.QFormLayout.LabelRole, self.defaultPrefixIPv4Label)
        self.defaultPrefixIPv4LineEdit = QtWidgets.QLineEdit(self.GeneralTab)
        self.defaultPrefixIPv4LineEdit.setObjectName("defaultPrefixIPv4LineEdit")
        self.formLayout.setWidget(4, QtWidgets.QFormLayout.FieldRole, self.defaultPrefixIPv4LineEdit)
        self.defaultPrefixIPv6Label = QtWidgets.QLabel(self.GeneralTab)
        self.defaultPrefixIPv6Label.setObjectName("defaultPrefixIPv6Label")
        self.formLayout.setWidget(5, QtWidgets.QFormLayout.LabelRole, self.defaultPrefixIPv6Label)
        self.defaultPrefixIPv6LineEdit = QtWidgets.QLineEdit(self.GeneralTab)
        self.defaultPrefixIPv6LineEdit.setObjectName("defaultPrefixIPv6LineEdit")
        self.formLayout.setWidget(5, QtWidgets.QFormLayout.FieldRole, self.defaultPrefixIPv6LineEdit)
        self.logfileLabel = QtWidgets.QLabel(self.GeneralTab)
        self.logfileLabel.setObjectName("logfileLabel")
        self.formLayout.setWidget(6, QtWidgets.QFormLayout.LabelRole, self.logfileLabel)
        self.logfileLineEdit = QtWidgets.QLineEdit(self.GeneralTab)
        self.logfileLineEdit.setObjectName("logfileLineEdit")
        self.formLayout.setWidget(6, QtWidgets.QFormLayout.FieldRole, self.logfileLineEdit)
        self.verticalLayout.addLayout(self.formLayout)
        self.debugCheckBox = QtWidgets.QCheckBox(self.GeneralTab)
        self.debugCheckBox.setObjectName("debugCheckBox")
        self.verticalLayout.addWidget(self.debugCheckBox)
        self.groupBox_4 = QtWidgets.QGroupBox(self.GeneralTab)
        self.groupBox_4.setMinimumSize(QtCore.QSize(0, 0))
        self.groupBox_4.setTitle("")
        self.groupBox_4.setFlat(True)
        self.groupBox_4.setObjectName("groupBox_4")
        self.horizontalLayout = QtWidgets.QHBoxLayout(self.groupBox_4)
        self.horizontalLayout.setContentsMargins(-1, 3, -1, 3)
        self.horizontalLayout.setObjectName("horizontalLayout")
        spacerItem = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout.addItem(spacerItem)
        self.revertButton = QtWidgets.QPushButton(self.groupBox_4)
        self.revertButton.setObjectName("revertButton")
        self.horizontalLayout.addWidget(self.revertButton)
        self.OkButton = QtWidgets.QPushButton(self.groupBox_4)
        self.OkButton.setDefault(True)
        self.OkButton.setObjectName("OkButton")
        self.horizontalLayout.addWidget(self.OkButton)
        self.verticalLayout.addWidget(self.groupBox_4)
        self.tabWidget.addTab(self.GeneralTab, "")
        self.iPv4Tab = QtWidgets.QWidget()
        self.iPv4Tab.setObjectName("iPv4Tab")
        self.verticalLayout_5 = QtWidgets.QVBoxLayout(self.iPv4Tab)
        self.verticalLayout_5.setObjectName("verticalLayout_5")
        self.verticalLayout_4 = QtWidgets.QVBoxLayout()
        self.verticalLayout_4.setObjectName("verticalLayout_4")
        self.iPv4ListWidget = QtWidgets.QListWidget(self.iPv4Tab)
        self.iPv4ListWidget.setFocusPolicy(QtCore.Qt.ClickFocus)
        self.iPv4ListWidget.setObjectName("iPv4ListWidget")
        self.verticalLayout_4.addWidget(self.iPv4ListWidget)
        self.iPv4LineEdit = QtWidgets.QLineEdit(self.iPv4Tab)
        self.iPv4LineEdit.setObjectName("iPv4LineEdit")
        self.verticalLayout_4.addWidget(self.iPv4LineEdit)
        self.groupBox_7 = QtWidgets.QGroupBox(self.iPv4Tab)
        self.groupBox_7.setMinimumSize(QtCore.QSize(0, 0))
        self.groupBox_7.setTitle("")
        self.groupBox_7.setFlat(True)
        self.groupBox_7.setObjectName("groupBox_7")
        self.horizontalLayout_4 = QtWidgets.QHBoxLayout(self.groupBox_7)
        self.horizontalLayout_4.setContentsMargins(-1, 3, -1, 3)
        self.horizontalLayout_4.setObjectName("horizontalLayout_4")
        spacerItem1 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_4.addItem(spacerItem1)
        self.iPv4MinusButton = QtWidgets.QPushButton(self.groupBox_7)
        self.iPv4MinusButton.setObjectName("iPv4MinusButton")
        self.horizontalLayout_4.addWidget(self.iPv4MinusButton)
        self.iPv4PlusButton = QtWidgets.QPushButton(self.groupBox_7)
        self.iPv4PlusButton.setDefault(True)
        self.iPv4PlusButton.setObjectName("iPv4PlusButton")
        self.horizontalLayout_4.addWidget(self.iPv4PlusButton)
        self.verticalLayout_4.addWidget(self.groupBox_7)
        self.groupBox_6 = QtWidgets.QGroupBox(self.iPv4Tab)
        self.groupBox_6.setMinimumSize(QtCore.QSize(0, 0))
        self.groupBox_6.setTitle("")
        self.groupBox_6.setFlat(True)
        self.groupBox_6.setObjectName("groupBox_6")
        self.horizontalLayout_3 = QtWidgets.QHBoxLayout(self.groupBox_6)
        self.horizontalLayout_3.setContentsMargins(-1, 3, -1, 3)
        self.horizontalLayout_3.setObjectName("horizontalLayout_3")
        spacerItem2 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_3.addItem(spacerItem2)
        self.iPv4RevertButton = QtWidgets.QPushButton(self.groupBox_6)
        self.iPv4RevertButton.setObjectName("iPv4RevertButton")
        self.horizontalLayout_3.addWidget(self.iPv4RevertButton)
        self.iPv4OkButton = QtWidgets.QPushButton(self.groupBox_6)
        self.iPv4OkButton.setDefault(True)
        self.iPv4OkButton.setObjectName("iPv4OkButton")
        self.horizontalLayout_3.addWidget(self.iPv4OkButton)
        self.verticalLayout_4.addWidget(self.groupBox_6)
        self.verticalLayout_5.addLayout(self.verticalLayout_4)
        self.tabWidget.addTab(self.iPv4Tab, "")
        self.IPv6Tab = QtWidgets.QWidget()
        self.IPv6Tab.setObjectName("IPv6Tab")
        self.verticalLayout_9 = QtWidgets.QVBoxLayout(self.IPv6Tab)
        self.verticalLayout_9.setObjectName("verticalLayout_9")
        self.iPv6ListWidget = QtWidgets.QListWidget(self.IPv6Tab)
        self.iPv6ListWidget.setFocusPolicy(QtCore.Qt.ClickFocus)
        self.iPv6ListWidget.setObjectName("iPv6ListWidget")
        self.verticalLayout_9.addWidget(self.iPv6ListWidget)
        self.iPv6LineEdit = QtWidgets.QLineEdit(self.IPv6Tab)
        self.iPv6LineEdit.setObjectName("iPv6LineEdit")
        self.verticalLayout_9.addWidget(self.iPv6LineEdit)
        self.groupBox_12 = QtWidgets.QGroupBox(self.IPv6Tab)
        self.groupBox_12.setMinimumSize(QtCore.QSize(0, 0))
        self.groupBox_12.setTitle("")
        self.groupBox_12.setFlat(True)
        self.groupBox_12.setObjectName("groupBox_12")
        self.horizontalLayout_9 = QtWidgets.QHBoxLayout(self.groupBox_12)
        self.horizontalLayout_9.setContentsMargins(-1, 3, -1, 3)
        self.horizontalLayout_9.setObjectName("horizontalLayout_9")
        spacerItem3 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_9.addItem(spacerItem3)
        self.iPv6MinusButton = QtWidgets.QPushButton(self.groupBox_12)
        self.iPv6MinusButton.setObjectName("iPv6MinusButton")
        self.horizontalLayout_9.addWidget(self.iPv6MinusButton)
        self.iPv6PlusButton = QtWidgets.QPushButton(self.groupBox_12)
        self.iPv6PlusButton.setDefault(True)
        self.iPv6PlusButton.setObjectName("iPv6PlusButton")
        self.horizontalLayout_9.addWidget(self.iPv6PlusButton)
        self.verticalLayout_9.addWidget(self.groupBox_12)
        self.groupBox_11 = QtWidgets.QGroupBox(self.IPv6Tab)
        self.groupBox_11.setMinimumSize(QtCore.QSize(0, 0))
        self.groupBox_11.setTitle("")
        self.groupBox_11.setFlat(True)
        self.groupBox_11.setObjectName("groupBox_11")
        self.horizontalLayout_8 = QtWidgets.QHBoxLayout(self.groupBox_11)
        self.horizontalLayout_8.setContentsMargins(-1, 3, -1, 3)
        self.horizontalLayout_8.setObjectName("horizontalLayout_8")
        spacerItem4 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_8.addItem(spacerItem4)
        self.iPv6RevertButton = QtWidgets.QPushButton(self.groupBox_11)
        self.iPv6RevertButton.setObjectName("iPv6RevertButton")
        self.horizontalLayout_8.addWidget(self.iPv6RevertButton)
        self.iPv6OkButton = QtWidgets.QPushButton(self.groupBox_11)
        self.iPv6OkButton.setDefault(True)
        self.iPv6OkButton.setObjectName("iPv6OkButton")
        self.horizontalLayout_8.addWidget(self.iPv6OkButton)
        self.verticalLayout_9.addWidget(self.groupBox_11)
        self.tabWidget.addTab(self.IPv6Tab, "")
        self.tab = QtWidgets.QWidget()
        self.tab.setObjectName("tab")
        self.verticalLayout_15 = QtWidgets.QVBoxLayout(self.tab)
        self.verticalLayout_15.setObjectName("verticalLayout_15")
        self.ignoredListWidget = QtWidgets.QListWidget(self.tab)
        self.ignoredListWidget.setFocusPolicy(QtCore.Qt.ClickFocus)
        self.ignoredListWidget.setObjectName("ignoredListWidget")
        self.verticalLayout_15.addWidget(self.ignoredListWidget)
        self.ignoredLineEdit = QtWidgets.QLineEdit(self.tab)
        self.ignoredLineEdit.setObjectName("ignoredLineEdit")
        self.verticalLayout_15.addWidget(self.ignoredLineEdit)
        self.groupBox_20 = QtWidgets.QGroupBox(self.tab)
        self.groupBox_20.setMinimumSize(QtCore.QSize(0, 0))
        self.groupBox_20.setTitle("")
        self.groupBox_20.setFlat(True)
        self.groupBox_20.setObjectName("groupBox_20")
        self.horizontalLayout_17 = QtWidgets.QHBoxLayout(self.groupBox_20)
        self.horizontalLayout_17.setContentsMargins(-1, 3, -1, 3)
        self.horizontalLayout_17.setObjectName("horizontalLayout_17")
        spacerItem5 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_17.addItem(spacerItem5)
        self.ignoredMinusButton = QtWidgets.QPushButton(self.groupBox_20)
        self.ignoredMinusButton.setObjectName("ignoredMinusButton")
        self.horizontalLayout_17.addWidget(self.ignoredMinusButton)
        self.ignoredPlusButton = QtWidgets.QPushButton(self.groupBox_20)
        self.ignoredPlusButton.setDefault(True)
        self.ignoredPlusButton.setObjectName("ignoredPlusButton")
        self.horizontalLayout_17.addWidget(self.ignoredPlusButton)
        self.verticalLayout_15.addWidget(self.groupBox_20)
        self.groupBox_21 = QtWidgets.QGroupBox(self.tab)
        self.groupBox_21.setMinimumSize(QtCore.QSize(0, 0))
        self.groupBox_21.setTitle("")
        self.groupBox_21.setFlat(True)
        self.groupBox_21.setObjectName("groupBox_21")
        self.horizontalLayout_18 = QtWidgets.QHBoxLayout(self.groupBox_21)
        self.horizontalLayout_18.setContentsMargins(-1, 3, -1, 3)
        self.horizontalLayout_18.setObjectName("horizontalLayout_18")
        spacerItem6 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_18.addItem(spacerItem6)
        self.ignoredRevertButton = QtWidgets.QPushButton(self.groupBox_21)
        self.ignoredRevertButton.setObjectName("ignoredRevertButton")
        self.horizontalLayout_18.addWidget(self.ignoredRevertButton)
        self.ignoredOkButton = QtWidgets.QPushButton(self.groupBox_21)
        self.ignoredOkButton.setDefault(True)
        self.ignoredOkButton.setObjectName("ignoredOkButton")
        self.horizontalLayout_18.addWidget(self.ignoredOkButton)
        self.verticalLayout_15.addWidget(self.groupBox_21)
        self.tabWidget.addTab(self.tab, "")
        self.verticalLayout_2.addWidget(self.tabWidget)

        self.retranslateUi(settingsTabWidget)
        self.tabWidget.setCurrentIndex(3)
        QtCore.QMetaObject.connectSlotsByName(settingsTabWidget)

    def retranslateUi(self, settingsTabWidget):
        _translate = QtCore.QCoreApplication.translate
        settingsTabWidget.setWindowTitle(_translate("settingsTabWidget", "Preferences"))
        self.masterServerLabel.setText(_translate("settingsTabWidget", "Master Server"))
        self.ddnsKeyFileLabel.setText(_translate("settingsTabWidget", "ddns Key File"))
        self.serverForZoneTransferLabel.setText(_translate("settingsTabWidget", "Server for Zone Transfer"))
        self.initialDomainLabel.setText(_translate("settingsTabWidget", "Initial Domain"))
        self.defaultPrefixIPv4Label.setText(_translate("settingsTabWidget", "Default Prefix IPv4"))
        self.defaultPrefixIPv6Label.setText(_translate("settingsTabWidget", "Default Prefix IPv6"))
        self.logfileLabel.setText(_translate("settingsTabWidget", "Logfile"))
        self.debugCheckBox.setText(_translate("settingsTabWidget", "Debug Log"))
        self.revertButton.setText(_translate("settingsTabWidget", "Revert"))
        self.OkButton.setText(_translate("settingsTabWidget", "Ok"))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.GeneralTab), _translate("settingsTabWidget", "General"))
        self.iPv4MinusButton.setText(_translate("settingsTabWidget", "-"))
        self.iPv4PlusButton.setText(_translate("settingsTabWidget", "+"))
        self.iPv4RevertButton.setText(_translate("settingsTabWidget", "Revert"))
        self.iPv4OkButton.setText(_translate("settingsTabWidget", "Ok"))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.iPv4Tab), _translate("settingsTabWidget", "IPv4 Nets"))
        self.iPv6MinusButton.setText(_translate("settingsTabWidget", "-"))
        self.iPv6PlusButton.setText(_translate("settingsTabWidget", "+"))
        self.iPv6RevertButton.setText(_translate("settingsTabWidget", "Revert"))
        self.iPv6OkButton.setText(_translate("settingsTabWidget", "Ok"))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.IPv6Tab), _translate("settingsTabWidget", "IPv6 Nets"))
        self.ignoredMinusButton.setText(_translate("settingsTabWidget", "-"))
        self.ignoredPlusButton.setText(_translate("settingsTabWidget", "+"))
        self.ignoredRevertButton.setText(_translate("settingsTabWidget", "Revert"))
        self.ignoredOkButton.setText(_translate("settingsTabWidget", "Ok"))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab), _translate("settingsTabWidget", "Ignored Zones"))
